@@ -1,5 +1,3 @@
-mod big_int_api_node;
-mod big_uint_api_node;
 mod blockchain_api_node;
 mod call_value_api_node;
 mod contract_self_api_node;
@@ -8,12 +6,11 @@ mod endpoint_arg_api_node;
 mod endpoint_finish_api_node;
 mod error_api_node;
 mod log_api_node;
+mod managed_types;
 mod send_api_node;
 mod storage_api_node;
 mod unsafe_buffer;
 
-pub use big_int_api_node::*;
-pub use big_uint_api_node::*;
 pub use blockchain_api_node::*;
 pub use call_value_api_node::*;
 pub use contract_self_api_node::*;
@@ -22,5 +19,6 @@ pub use endpoint_arg_api_node::*;
 pub use endpoint_finish_api_node::*;
 pub use error_api_node::*;
 pub use log_api_node::*;
+pub use managed_types::*;
 pub use send_api_node::*;
 pub use storage_api_node::*;
